/* jsUnit */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Edward Hieatt code.
 *
 * The Initial Developer of the Original Code is
 * Edward Hieatt, edward@jsunit.net.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 * Edward Hieatt, edward@jsunit.net (original author)
 * Bob Clary, bc@bclary.com
 * Curt Arnold carnold@houston.rr.com
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

function jsUnitTestCase(name) {
  this.isjsUnitTestCase = true;
  this.name = name;
  this.configPage = null;
  this.ready = true;
  this.listeners = null;
  this.completed = false;
  this.timeout = null;
  this.ignored = false;
}

jsUnitTestCase.prototype.clone = function() {
  var newTest = new jsUnitTestCase(this.name);
  newTest.configPage = this.configPage;
  newTest.ready = this.ready;
  newTest.ignored = this.ignored;
  newTest.runTest = this.runTest;
  newTest.setUp = this.setUp;
  newTest.tearDown = this.tearDown;
  newTest.getTests = this.getTests;
  return newTest;
}

jsUnitTestCase.prototype.runTest = function () {    
   top.fail("runTest not overriden");
}

jsUnitTestCase.prototype.setUp = function () {
    this.ready = true;
    this.ignored = false;
    this.completed = false;
}

jsUnitTestCase.prototype.tearDown = function () {    
}


jsUnitTestCase.prototype.getTests = function () {
    return [ this ];
}


jsUnitTestCase.prototype.addListener = function(listener) {
    if (this.listeners == null) {
        this.listeners = new Array();
    }
    this.listeners[this.listeners.length] = listener;
}

jsUnitTestCase.prototype.setReady = function(ready) {
    if (this.ready != ready) {
        this.ready = ready;
        if (ready && this.listeners != null) {
            for (i = 0; i < this.listeners.length; i++) {
                this.listeners[i].onTestReady(this);
            }
        }
    }
}
          
jsUnitTestCase.prototype.fail = function(msg) {
    if (ready) {
        top.fail(msg);
    } else {         
        if (this.listeners != null) {
            for (i = 0; i < this.listeners.length; i++) {
                this.listeners[i].onTestFail(this, msg);
            }
        }
    }
}
            

//
//  appears meaningless
//
jsUnitTestCase.prototype.containsTestPages = function() {
    return true;
}

jsUnitTestCase.prototype.hasMorePages = function() {
    return false;
}

jsUnitTestCase.prototype.nextPage = function() {
    return null;
}


